/**********************************************************
 FILE: runcon_act.c
 author: C. Timmermans, University of Michigan
 **********************************************************/
/**********************************************************
 This file contains the actions taken by operator when a button
 is clicked. The general form is:

 int routine()
 {
 actions
 }

 Note that although the routine is defined to be an integer, its return
 code is not used. Examples, using some of the standard UNIDAQ routines
 are given below
 ***************************************************************/

/************************************************************************
*                                                                       *
* Copyright (c) 1993                                                    *
* The Regents of The University of Michigan                             *
* Universities Research Association, Inc.                               *
* All Rights Reserved                                                   *
*                                                                       *
*                Authors:                                               *
*                        R. Ball, C. Timmermans, UofM                   *
*                        Y. Takeuchi, T.I.T.                            *
*                        M. Nomachi, KEK                                *
*                        A. Fry, C. Erbas, D. Brenner, SSCL             *
*                                                                       *
************************************************************************/

#include "generic.h"
#include "sdc_pack_msg_c.h"

extern char collector[];
extern char runcontrol[];

int act_warm()
/**********************************************
 performing a warm start. First the run state is 
 checked. This is followed by sending the BEGIN_RUN_WARM
 command to runcontrol. The action is logged into the logbook
 ***********************************************/
{
  short s;
  int status;

  if(read_value_from_sp(collector,"runstate",&s,&status) != 0) return(0);
  if(status == END_STATE) { 
    Send_Message(runcontrol,"BEGIN_RUN_WARM");
    add_err_string("BEGIN_RUN_WARM");
    send_err_string(Oper_Send_OK);
  }
  else {
    add_err_string("BEGIN_RUN_WARM");
    send_err_string(Oper_NotCompat);
  }
}

int act_cold()
/**********************************************
 performing a cold start. First the run state is 
 checked. This is followed by sending the BEGIN_RUN_COLD
 command to runcontrol. The action is logged in the logbook.
 ***********************************************/
{
  short s;
  int status;

  if(read_value_from_sp(collector,"runstate",&s,&status) != 0) return(0);
  if(status == END_STATE) { 
    Send_Message(runcontrol,"BEGIN_RUN_COLD");
    add_err_string("BEGIN_RUN_COLD");
    send_err_string(Oper_Send_OK);
  }
  else {
    add_err_string("BEGIN_RUN_COLD");
    send_err_string(Oper_NotCompat);
  }
}

int act_stop()
/**********************************************
 stopping a run. First the run state is 
 checked. This is followed by sending the STOP_RUN
 command to runcontrol. The action is logged in the logbook.
 ***********************************************/
{
  short s;
  int status;

  if(read_value_from_sp(collector,"runstate",&s,&status) != 0) return(0);
  if(status != END_STATE) { 
    Send_Message(runcontrol,"STOP_RUN");
    add_err_string("STOP_RUN");
    send_err_string(Oper_Send_OK);
  }
  else {
    add_err_string("STOP_RUN");
    send_err_string(Oper_NotCompat);
  }
}

int act_cont()
/**********************************************
 continuing a run. First the run state is 
 checked. This is followed by sending the CONTINUE_RUN
 command to runcontrol. The action is logged in the logbook.
 ***********************************************/
{
  short s;
  int status;

  if(read_value_from_sp(collector,"runstate",&s,&status) != 0) return(0);
  if(status == PAUSE_STATE) { 
    Send_Message(runcontrol,"CONTINUE_RUN");
    add_err_string("CONTINUE_RUN");
    send_err_string(Oper_Send_OK);
  }
  else {
    add_err_string("CONTINUE_RUN");
    send_err_string(Oper_NotCompat);
  }
}

int act_pause()
/**********************************************
 suspending a run. First the run state is 
 checked. This is followed by sending the SUSPEND_RUN
 command to runcontrol. The action is logged in the logbook.
 ***********************************************/
{
  short s;
  int status;

  if(read_value_from_sp(collector,"runstate",&s,&status) != 0) return(0);
  if(status == RESUME_STATE) { 
    Send_Message(runcontrol,"SUSPEND_RUN");
    add_err_string("SUSPEND_RUN");
    send_err_string(Oper_Send_OK);
  }
  else {
    add_err_string("SUSPEND_RUN");
    send_err_string(Oper_NotCompat);
  }
}

int act_dwnld()
/**********************************************
 Downloading. First the run state is 
 checked. This is followed by sending the DOWNLOAD
 command to runcontrol. The action is logged in the logbook.
 ***********************************************/
{
  short s;
  int status;

  if(read_value_from_sp(collector,"runstate",&s,&status) != 0) return(0);
  if(status == END_STATE) { 
    Send_Message(runcontrol,"DOWNLOAD");
    add_err_string("DOWNLOAD");
    send_err_string(Oper_Send_OK);
  }
  else {
    add_err_string("DOWNLOAD");
    send_err_string(Oper_NotCompat);
  }
}

int act_init()
/**********************************************
 Initializing variables. First the run state is 
 checked. This is followed by sending the INITIALIZE
 command to runcontrol. The action is logged in the logbook.
 ***********************************************/
{
  short s;
  int status;

  if(read_value_from_sp(collector,"runstate",&s,&status) != 0) return(0);
  if(status == END_STATE) { 
    Send_Message(runcontrol,"INITIALIZE");
    add_err_string("INITIALIZE");
    send_err_string(Oper_Send_OK);
  }
  else {
    add_err_string("INITIALIZE");
    send_err_string(Oper_NotCompat);
  }
}
